mirror of
https://github.com/opencv/opencv.git
synced 2026-07-30 07:43:03 +04:00
Merge pull request #10846 from luzpaz:misc-modules-typos-cont
This commit is contained in:
@@ -382,7 +382,7 @@ the DefaultAllocator since the stack for pool1 is full.
|
||||
@endcode
|
||||
|
||||
If a third stream is declared in the above example, allocating with #getBuffer
|
||||
within that stream will also be carried out by the DefaultAllocator becuase we've run out of
|
||||
within that stream will also be carried out by the DefaultAllocator because we've run out of
|
||||
stacks.
|
||||
|
||||
@code
|
||||
|
||||
@@ -106,7 +106,7 @@ namespace cv { namespace cuda { namespace device
|
||||
}
|
||||
|
||||
template<typename InIt, typename OutIt, class UnOp>
|
||||
static __device__ __forceinline__ void transfrom(InIt beg, InIt end, OutIt out, UnOp op)
|
||||
static __device__ __forceinline__ void transform(InIt beg, InIt end, OutIt out, UnOp op)
|
||||
{
|
||||
int STRIDE = stride();
|
||||
InIt t = beg + flattenedThreadId();
|
||||
@@ -117,7 +117,7 @@ namespace cv { namespace cuda { namespace device
|
||||
}
|
||||
|
||||
template<typename InIt1, typename InIt2, typename OutIt, class BinOp>
|
||||
static __device__ __forceinline__ void transfrom(InIt1 beg1, InIt1 end1, InIt2 beg2, OutIt out, BinOp op)
|
||||
static __device__ __forceinline__ void transform(InIt1 beg1, InIt1 end1, InIt2 beg2, OutIt out, BinOp op)
|
||||
{
|
||||
int STRIDE = stride();
|
||||
InIt1 t1 = beg1 + flattenedThreadId();
|
||||
|
||||
@@ -1361,7 +1361,7 @@ CvGraph;
|
||||
|
||||
/** @} */
|
||||
|
||||
/*********************************** Chain/Countour *************************************/
|
||||
/*********************************** Chain/Contour *************************************/
|
||||
|
||||
typedef struct CvChain
|
||||
{
|
||||
|
||||
@@ -108,13 +108,13 @@
|
||||
" return result;",
|
||||
"\n",
|
||||
" } catch(const cv::Exception& e) {",
|
||||
" LOGD(\"Core::n_1minMaxLoc() catched cv::Exception: %s\", e.what());",
|
||||
" LOGD(\"Core::n_1minMaxLoc() caught cv::Exception: %s\", e.what());",
|
||||
" jclass je = env->FindClass(\"org/opencv/core/CvException\");",
|
||||
" if(!je) je = env->FindClass(\"java/lang/Exception\");",
|
||||
" env->ThrowNew(je, e.what());",
|
||||
" return NULL;",
|
||||
" } catch (...) {",
|
||||
" LOGD(\"Core::n_1minMaxLoc() catched unknown exception (...)\");",
|
||||
" LOGD(\"Core::n_1minMaxLoc() caught unknown exception (...)\");",
|
||||
" jclass je = env->FindClass(\"java/lang/Exception\");",
|
||||
" env->ThrowNew(je, \"Unknown exception in JNI code {core::minMaxLoc()}\");",
|
||||
" return NULL;",
|
||||
|
||||
Reference in New Issue
Block a user